@@ -29,9 +29,6 @@ num_benchmark_iteration = 30
 # print info for debugging purpose
 logging_level = logging.INFO
 
-# benchmark accuracy mode
-eval_accuracy = False
-
 # print code line info for debug use
 print_code_line_info = False
 
@@ -99,4 +96,4 @@ def reset_globals():
 
     list_calib_dataloader_name = []
     list_eval_func_lines = []
-    list_eval_func_name = []
\ No newline at end of file
+    list_eval_func_name = []
