@@ -29,7 +29,6 @@ def enable(
     features,
     target_batch_size=1,  # effective for feature "pytorch_change_batch_size"
     num_benchmark_iteration=10,  # effective for feature "pytorch_benchmark"
-    eval_accuracy=False,
     generate_patch=True,
     overwrite=False,
     save_patch_path="",
@@ -149,8 +148,6 @@ def enable(
 
     globals.num_benchmark_iteration = str(num_benchmark_iteration + 10) # 10: warmup iteration number
 
-    globals.eval_accuracy = eval_accuracy
-
     globals.cache_load_transformers = cache_load_transformers
 
     # move "pytorch_benchmark" to the last
@@ -563,7 +560,7 @@ def bench(
     count_P90 = 0
     P99 = 0
     count_P99 = 0
-    acc = 0
+    acc_delta = 0
     for line in bench_log:
         if "Neural_Coder_Bench_IPS" in line:
             try:
@@ -594,9 +591,11 @@ def bench(
                 count_P99 += 1
             except ValueError as ve:
                 pass
-        if "Acc@5" in line:
+        if "Accuracy (int8|fp32)" in line:
             try:
-                acc += float(line[line.find(":")+3:])
+                acc_int8 = float(line[line.find("Accuracy")+22:line.find("Accuracy")+28])
+                acc_fp32 = float(line[line.find("Accuracy")+29:line.find("Accuracy")+35])
+                acc_delta = round((acc_int8 - acc_fp32) / acc_fp32 * 100, 2) # percent of increase/decrease
             except ValueError as ve:
                 pass
 
@@ -634,7 +633,7 @@ def bench(
     logger.info(f"Collected latency_p50 on the code is: [{P50}] (mspi)")
     logger.info(f"Collected latency_p90 on the code is: [{P90}] (mspi)")
     logger.info(f"Collected latency_p99 on the code is: [{P99}] (mspi)")
-    logger.info(f"Collected accuracy on the code is: [{acc}]")
+    logger.info(f"Collected accuracy delta on the code is: [{acc_delta}]")
 
     # unpatch
     if patch_path != "":
@@ -642,7 +641,7 @@ def bench(
             "patch -R -d/ -p0 < " + patch_path, env=os.environ, shell=True, stdout=subprocess.PIPE)  # nosec
         sp_unpatch.wait()
 
-    return [FPS, MSPI, P50, P90, P99, acc], mode, os.path.abspath(ws_path)
+    return [FPS, MSPI, P50, P90, P99, acc_delta], mode, os.path.abspath(ws_path)
 
 
 def superbench(
@@ -661,7 +660,6 @@ def superbench(
     ncore_per_instance=-1,  # only for "self_defined" mode
     ninstances=-1,  # only for "self_defined" mode
     bench_batch_size=-1,  # only for "self_defined" mode
-    eval_accuracy=False,
     auto_quant=False,
 ):
 
@@ -820,24 +818,7 @@ def superbench(
                     ncore_per_instance=ncore_per_instance,
                     ninstances=ninstances,
                     bench_batch_size=bench_batch_size,
-                    eval_accuracy=False,
                 )
-                if eval_accuracy:
-                    bench_acc, bench_mode, bench_ws_path = enable(
-                        code=code,
-                        entry_code=entry_code,
-                        args=args,
-                        features=features,
-                        mode=mode,
-                        run_bench=True,
-                        num_benchmark_iteration=num_benchmark_iteration,
-                        cpu_set_env=cpu_set_env,
-                        ncore_per_instance=ncore_per_instance,
-                        ninstances=ninstances,
-                        bench_batch_size=bench_batch_size,
-                        eval_accuracy=True,
-                    )
-
 
                 if dry_run:
                     t_end = time.time()
@@ -869,86 +850,54 @@ def superbench(
                     elif features == []:
                         features_display = "The Original Model"
 
-                    if not eval_accuracy:
-                        logger.info(
-                            f"Benchmark result (performance) of {features_display}"
-                            f" is {bench_performance[0]} (FPS)")
-                    else:
-                        logger.info(
-                            f"Benchmark result (performance) of {features_display}"
-                            f" is {bench_performance[0]} (FPS)")
-                        logger.info(
-                            f"Benchmark result (accuracy) of {features_display} is {bench_acc[5]}")
+                    logger.info(
+                        f"Benchmark result (performance) of {features_display}"
+                        f" is {bench_performance[0]} (FPS)")
+                    logger.info(
+                        f"Benchmark result (accuracy delta) of {features_display} is {bench_performance[5]} %")
                 else:
-                    if not eval_accuracy:
-                        logger.info(
-                            f"Benchmark result (performance) of optimization set [{features}]"
-                            f" is [{bench_performance[0]}] (FPS)")
-                    else:
-                        logger.info(
-                            f"Benchmark result (performance) of optimization set [{features}]"
-                            f" is [{bench_performance[0]}] (FPS)")
-                        logger.info(
-                            f"Benchmark result (accuracy) of optimization set [{features}] is [{bench_acc[5]}]")
+                    logger.info(
+                        f"Benchmark result (performance) of optimization set [{features}]"
+                        f" is [{bench_performance[0]}] (FPS)")
+                    logger.info(
+                        f"Benchmark result (accuracy delta) of optimization set [{features}]"
+                        f" is [{bench_performance[5]}] %")
 
                 d = {}  # initialize dict
                 d["features"] = features
                 d["FPS"] = bench_performance[0]
-                if eval_accuracy:
-                    d["accuracy"] = bench_acc[5]
+                d["accuracy"] = bench_performance[5]
                 d["mode"] = bench_mode
                 d["workspace_path"] = bench_ws_path
                 result.append(d)
 
                 list_FPS.append(bench_performance[0])
-                if eval_accuracy:
-                    list_accuracy.append(bench_acc[5])
+                list_accuracy.append(bench_performance[5])
                 list_features.append(features)
                 list_mode.append(bench_mode)
                 list_ws_path.append(bench_ws_path)
 
         # print result
-        if not eval_accuracy:
-            print(f"Superbench result of sweeping [{sweep_objective}] printed below with sorted FPS: ")
-            print("{:<20} {:<20} {:<120}".format(
-                'Numactl Mode', 'Performance (FPS)', 'Features Applied'))
+        print(f"Superbench result of sweeping [{sweep_objective}] printed below with sorted FPS: ")
+        print("{:<20} {:<20} {:<20} {:<120}".format(
+            'Numactl Mode', 'Performance (FPS)', 'Accuracy Delta (%)', 'Features Applied'))
 
-            sort_index = sorted(
-                range(len(list_FPS)),
-                key=lambda k: list_FPS[k],
-                reverse=True,
-            )
+        sort_index = sorted(
+            range(len(list_FPS)),
+            key=lambda k: list_FPS[k],
+            reverse=True,
+        )
 
-            for i in sort_index:
-                if list_FPS[i] != 0:
-                    print(
-                        "{:<20} {:<20} {:<120}".format(
-                            str(list_mode[i]),
-                            str(list_FPS[i]),
-                            str(list_features[i]),
-                        )
-                    )
-        else:
-            print(f"Superbench result of sweeping [{sweep_objective}] printed below with sorted FPS: ")
-            print("{:<20} {:<20} {:<20} {:<120}".format(
-                'Numactl Mode', 'Performance (FPS)', 'Accuracy', 'Features Applied'))
-
-            sort_index = sorted(
-                range(len(list_FPS)),
-                key=lambda k: list_FPS[k],
-                reverse=True,
-            )
-
-            for i in sort_index:
-                if list_FPS[i] != 0:
-                    print(
-                        "{:<20} {:<20} {:<20} {:<120}".format(
-                            str(list_mode[i]),
-                            str(list_FPS[i]),
-                            str(list_accuracy[i]),
-                            str(list_features[i]),
-                        )
+        for i in sort_index:
+            if list_FPS[i] != 0:
+                print(
+                    "{:<20} {:<20} {:<20} {:<120}".format(
+                        str(list_mode[i]),
+                        str(list_FPS[i]),
+                        str(list_accuracy[i]),
+                        str(list_features[i]),
                     )
+                )
 
         # for superbench report generation
         list_optimization_set_top3 = []
@@ -1064,7 +1013,6 @@ def superbench(
                             ncore_per_instance=ncore_per_instance,
                             ninstances=ninstances,
                             bench_batch_size=bench_batch_size,
-                            eval_accuracy=eval_accuracy,
                         )
 
                         if dry_run:
@@ -1145,7 +1093,6 @@ def superbench(
 #     code,
 #     save_path="superbench_report.pdf",
 #     logging_level="info",
-#     eval_accuracy=False,
 #     platform="bare_metal",
 #     bare_metal_machine_type="SPR",
 # ):
@@ -1158,7 +1105,6 @@ def superbench(
 #         sweep_objective="feature",
 #         mode="throughput",
 #         logging_level=logging_level,
-#         eval_accuracy=eval_accuracy,
 #     )
 
 #     res5, res6, res7, res8 = superbench(
@@ -1166,7 +1112,6 @@ def superbench(
 #         sweep_objective="bench_config",
 #         bench_feature=res1[0],
 #         logging_level=logging_level,
-#         eval_accuracy=eval_accuracy,
 #     )
 #     res1[0] = res1[0][0:-2]
 
@@ -1233,7 +1178,6 @@ def auto_quant(
     ncore_per_instance=-1,  # only for "self_defined" mode
     ninstances=-1,  # only for "self_defined" mode
     bench_batch_size=-1,  # only for "self_defined" mode
-    eval_accuracy=False,
 ):
     return superbench(
         code,
@@ -1250,6 +1194,5 @@ def auto_quant(
         ncore_per_instance=ncore_per_instance,  # only for "self_defined" mode
         ninstances=ninstances,  # only for "self_defined" mode
         bench_batch_size=bench_batch_size,  # only for "self_defined" mode
-        eval_accuracy=eval_accuracy,
         auto_quant=True,
     )
