@@ -16,3 +16,14 @@
 # limitations under the License.
 #
 
+from os.path import dirname, basename, isfile, join
+import glob
+from .ops import OPERATORS
+
+modules = glob.glob(join(dirname(__file__), "*.py"))
+
+for f in modules:
+    if isfile(f) and not f.startswith('__') and not f.endswith('__init__.py'):
+        __import__(basename(f)[:-3], globals(), locals(), level=1)
+
+__all__ = ["OPERATORS"]
\ No newline at end of file
