@@ -17,30 +17,45 @@
 #
 
 import onnx
-from .base_operator import QuantOperatorBase
-from neural_compressor.adaptor.ox_utils.util import QuantizedValueType, attribute_to_kwarg
-from onnx import onnx_pb as onnx_proto
-from neural_compressor.adaptor.ox_utils.util import QuantizedValue
-'''
-    Quantize Gather
-'''
+from neural_compressor.adaptor.ox_utils.operators.ops import op_registry, Operator
+from neural_compressor.adaptor.ox_utils.util import attribute_to_kwarg
 
-class GatherConverter(QuantOperatorBase):
+@op_registry(op_types="Gather")
+class GatherOperator(Operator):
     def __init__(self, onnx_quantizer, onnx_node):
-        super().__init__(onnx_quantizer, onnx_node)
+        super(GatherOperator, self).__init__(onnx_quantizer, onnx_node)
 
-    def convert(self):
+    def quantize_check(self):
         node = self.node
-        assert node.op_type in ["Gather"]
+        if not self.quantizer.is_valid_quantize_weight(node.input[0]):
+            return False
+        return True
 
-        if len(self.quantizer.model.get_children(node)) == 0 or \
-            not node.name.endswith('_quant'):
-            return
+    def quantize(self):
+        node = self.node
+        self.quantizer.quantize_inputs(node, [0])
+        if not self.disable_qdq_for_node_output or self.quantizer != 'qdq':
+            self.quantizer.quantize_outputs(node)
+        node.name = node.name + "_quant"
+
+    def convert_check(self, convert_format):
+        node = self.node
+        assert convert_format in ['dynamic', 'static'], \
+            "convert format for {} should be in ['dynamic', 'static']".format(node.op_type)
+
+        parents = self.quantizer.model.get_parents(node)
+        children = self.quantizer.model.get_children(node)
+        if len(children) == 0 or len(parents) == 0 or not node.name.endswith('_quant'):
+            return False
+        
+        return True
+
+    def convert(self, convert_format):
+        node = self.node
+        
         parents = self.quantizer.model.get_parents(node)
         children = self.quantizer.model.get_children(node)
 
-        if len(parents) == 0:
-            return
         if any([i.op_type == 'DequantizeLinear' for i in parents]):
             inputs = []
             inputs.append(parents[0].input[0])
@@ -49,7 +64,7 @@ class GatherConverter(QuantOperatorBase):
             gather_new_output = node.output[0] + "_quantized"
 
             kwargs = {}
-            for attribute in node.attribute:
+            for attribute in node.attribute: # pragma: no cover
                 kwargs.update(attribute_to_kwarg(attribute))
 
             gather_node = onnx.helper.make_node("Gather",
@@ -58,7 +73,7 @@ class GatherConverter(QuantOperatorBase):
                                                 node.name,
                                                 **kwargs)
             self.quantizer.new_nodes.append(gather_node)
-            if any([i.op_type  != 'QuantizeLinear' for i in children]):
+            if any([i.op_type  != 'QuantizeLinear' for i in children]): # pragma: no cover
                 dq_inputs = []
                 dq_inputs.append(gather_new_output)
                 dq_inputs.extend(parents[0].input[1:])
@@ -74,19 +89,4 @@ class GatherConverter(QuantOperatorBase):
                     for n in self.quantizer.model.get_children(child):
                         self.quantizer.model.replace_node_input(n, 
                                         child.output[0], gather_new_output)
-            self.quantizer.remove_nodes.extend([node, parents[0]])
-
-class GatherQuant(QuantOperatorBase):
-    def __init__(self, onnx_quantizer, onnx_node):
-        super().__init__(onnx_quantizer, onnx_node)
-
-    def quantize(self):
-        node = self.node
-        assert (node.op_type == "Gather")
-
-        if not self.quantizer.is_valid_quantize_weight(node.input[0]):
-            return
-        self.quantizer.quantize_inputs(node, [0])
-        if not self.disable_qdq_for_node_output or self.quantizer != 'qdq':
-            self.quantizer.quantize_outputs(node)
-        node.name = node.name + "_quant"
+            self.quantizer.remove_nodes.extend([node, parents[0]])
\ No newline at end of file
