@@ -17,15 +17,13 @@
 #
 
 import onnx
-from neural_compressor.adaptor.ox_utils.util import QuantizedValueType, \
-                                                 attribute_to_kwarg
-from .base_operator import QuantOperatorBase 
-from neural_compressor.adaptor.ox_utils.util import QuantizedValue
-from .qdq_base_operator import QDQOperatorBase
+from neural_compressor.adaptor.ox_utils.operators.ops import op_registry, Operator
+from neural_compressor.adaptor.ox_utils.util import attribute_to_kwarg
 
-class QDQSplit(QDQOperatorBase):
+@op_registry(op_types="Split")
+class SplitOperator(Operator):
     def __init__(self, onnx_quantizer, onnx_node):
-        super().__init__(onnx_quantizer, onnx_node)
+        super(SplitOperator, self).__init__(onnx_quantizer, onnx_node)
 
     def quantize(self):
         node = self.node
@@ -34,24 +32,29 @@ class QDQSplit(QDQOperatorBase):
             self.quantizer.quantize_outputs(self.node, direct_int8=True)
         node.name = node.name + "_quant"
 
-class QSplit(QuantOperatorBase):
-    def __init__(self, onnx_quantizer, onnx_node):
-        super().__init__(onnx_quantizer, onnx_node)
-
-    def convert(self):
+    def convert_check(self, convert_format):
         node = self.node
+        assert convert_format in ['static'], \
+            "convert format for {} should be in ['static']".format(node.op_type)
+            
         parent = self.quantizer.model.get_parents(node)[0]
         children = self.quantizer.model.get_children(node)
         if parent.op_type != 'DequantizeLinear' or len(children) == 0 or \
-            not node.name.endswith('_quant'):
-            return
+            not node.name.endswith('_quant'): # pragma: no cover
+            return False
+        return True
+
+    def convert(self, convert_format):
+        node = self.node
+
+        parent = self.quantizer.model.get_parents(node)[0]
         kwargs = {}
-        for attribute in node.attribute:
+        for attribute in node.attribute: # pragma: no cover
             kwargs.update(attribute_to_kwarg(attribute))
 
         quantized_input_names = []
         quantized_input_names.append(parent.input[0])
-        if len(node.input) > 1:
+        if len(node.input) > 1: # pragma: no cover
             quantized_input_names.extend(node.input[1:])
         outputs = []
         for output in node.output:
@@ -60,9 +63,9 @@ class QSplit(QuantOperatorBase):
                 if child.op_type == 'QuantizeLinear':
                     self.quantizer.remove_nodes.append(child)
                     outputs.append(child.output[0])
-                else:
+                else: # pragma: no cover
                     outputs.append(output)
-            else:
+            else: # pragma: no cover
                 outputs.append(output + '_quatized')
 
         quantized_node = onnx.helper.make_node(node.op_type, 
@@ -71,3 +74,9 @@ class QSplit(QuantOperatorBase):
                                                node.name, **kwargs)
         self.quantizer.new_nodes.append(quantized_node)
         self.quantizer.remove_nodes.extend([parent, node])
+
+    def cast(self): # pragma: no cover
+        node = self.node
+        if node.input[0] not in [i.tensor_name for i in self.quantizer.new_value_info.values()]:
+            return
+        self.quantizer.dtype_cast(self.node, self.dtype)
\ No newline at end of file
