@@ -39,6 +39,7 @@ class TensorFlowAdaptor(Adaptor):
         "Conv3D": "conv3d",
         "DepthwiseConv2dNative": "conv2d",
         "FusedBatchNormV3": "batchnorm",
+        "_MklFusedInstanceNorm": "instancenorm",
         "MaxPool": "pooling",
         "MaxPool3D": "pooling",
         "AvgPool": "pooling",
@@ -46,11 +47,15 @@ class TensorFlowAdaptor(Adaptor):
         "MatMul": "matmul",
         "BatchMatMul": "matmul",
         "BatchMatMulV2": "matmul",
-        "Pad": "pad"
+        "Pad": "pad",
+        "Conv2DBackpropInput": "deconv2d",
+        "Conv3DBackpropInputV2": "deconv3d"
     }
     def __init__(self, framework_specific_info):
         super().__init__(framework_specific_info)
 
+        os.environ["CUDA_DEVICE_ORDER"] = "PCI_BUS_ID"
+        os.environ['CUDA_VISIBLE_DEVICES'] = "-1"
         self.quantize_config = {'op_wise_config': {}}
         self.framework_specific_info = framework_specific_info
         self.approach = deep_get(self.framework_specific_info, 'approach', False)
@@ -71,8 +76,11 @@ class TensorFlowAdaptor(Adaptor):
         self.query_handler = TensorflowQuery(local_config_file=os.path.join(
             os.path.dirname(__file__), cfg_yaml_name), performance_only=self.performance_only)
         self.itex_mode = cfg_yaml_name == 'tensorflow_itex.yaml'
-        self.qdq_enabled = cfg_yaml_name == 'inteltensorflow.yaml' or \
-                                   cfg_yaml_name == 'tensorflow_itex.yaml'
+
+        from pkg_resources import parse_version
+        import tensorflow as tf
+        self.new_api = True if parse_version(tf.version.VERSION) == parse_version('2.11.0202242') else False
+        self.qdq_enabled = cfg_yaml_name == 'tensorflow_itex.yaml' or self.new_api
         self.op_wise_sequences = self.query_handler.get_eightbit_patterns(self.qdq_enabled)
         self.optimization = self.query_handler.get_grappler_optimization_cfg()
 
@@ -80,7 +88,8 @@ class TensorFlowAdaptor(Adaptor):
         self.fp32_preds_as_label = False
         self.benchmark = (GLOBAL_STATE.STATE == MODE.BENCHMARK)
         self.callbacks = []
-        self.new_api = False
+
+        self.optype_statistics = None
 
     def log_histogram(self, writer, tag, values, step=0, bins=1000):
         import tensorflow as tf
@@ -266,7 +275,7 @@ class TensorFlowAdaptor(Adaptor):
             output_postfix = "_fp32.output"
             inspect_node_types = ["Conv2D", "DepthwiseConv2dNative", "MaxPool", "AvgPool",
                                   "ConcatV2", "MatMul", "FusedBatchNormV3", "FusedBatchNorm", "BiasAdd",
-                                  "Relu", "Relu6", "Dequantize"]
+                                  "_MklFusedInstanceNorm", "Relu", "Relu6", "Dequantize"]
             fp32_inspect_node_name = []
             int8_inspect_node_name = []
             q_node_scale = {}
@@ -314,7 +323,7 @@ class TensorFlowAdaptor(Adaptor):
                 # Inspect weights, bias. Need further optimize
                 if node.op == "Const" and graph_info[graph_info[node.name].outputs[0]].node.op \
                     in ["Conv2D", "DepthwiseConv2dNative", "MatMul",
-                    "FusedBatchNormV3", "BiasAdd"]:
+                    "FusedBatchNormV3", "_MklFusedInstanceNorm", "BiasAdd"]:
                     const_value = tensor_util.MakeNdarray(node.attr.get(
                                   'value').tensor).astype(np.float32)
                     self.log_histogram(writer, node.name, const_value)
@@ -519,7 +528,8 @@ class TensorFlowAdaptor(Adaptor):
 
             return self.convert(common.Model(qat_model), 'QAT', 'default')
 
-        assert q_func is None, "quantization aware training mode is not support on tensorflow"
+        assert q_func is None, \
+            "post-training quantization mode is not support calibration function for Tensorflow!"
         self.tuning_cfg_to_fw(tune_cfg)
         logger.debug("Dump quantization configurations:")
         logger.debug(self.quantize_config)
@@ -604,11 +614,12 @@ class TensorFlowAdaptor(Adaptor):
         fp32_op_list=list(set(fp32_op_list_uint8).union(set(fp32_op_list_int8)))
 
 
-        int8_op_prefix_list = ['QuantizedConv2D', '_QuantizedConv3D', 'QuantizedDepthwise',
+        int8_op_prefix_list = ['QuantizedConv2D', '_FusedQuantizedConv3D', 'QuantizedDepthwise',
                                'QuantizedMaxPool', 'QuantizedAvgPool',
                                'QuantizedConcatV2', 'QuantizedMatMul',
                                '_QuantizedFusedBatchNorm', '_QuantizedMatMul',
-                               '_QuantizedBatchMatMul']
+                               '_QuantizedBatchMatMul', '_QuantizedFusedInstanceNorm',
+                               '_FusedQuantizedDeconv2D', '_FusedQuantizedDeconv3D']
         from tensorflow.python.framework import dtypes
 
         res = {}
@@ -627,10 +638,16 @@ class TensorFlowAdaptor(Adaptor):
                 origin_op_type = possible_int8_res[0].split('Quantized')[-1]
                 if origin_op_type == 'FusedBatchNorm':
                     origin_op_type = 'FusedBatchNormV3'
+                if origin_op_type == 'FusedInstanceNorm':
+                    origin_op_type = '_MklFusedInstanceNorm'
                 if origin_op_type == 'Depthwise':
                     origin_op_type = 'DepthwiseConv2dNative'
                 if origin_op_type == 'BatchMatMul':
                     origin_op_type = 'BatchMatMulV2'
+                if origin_op_type == 'Deconv2D':
+                    origin_op_type = 'Conv2DBackpropInput'
+                if origin_op_type == 'Deconv3D':
+                    origin_op_type = 'Conv3DBackpropInputV2'
                 res[origin_op_type]['INT8'] += 1
 
             if i.op in fp32_op_list:
@@ -647,12 +664,17 @@ class TensorFlowAdaptor(Adaptor):
                         res[i.op]['FP32'] += 1
                 else:
                     res[i.op]['FP32'] += 1
-        output_data = [[op_type, sum(res[op_type].values()), res[op_type]['INT8'],
-                        res[op_type]['BF16'], res[op_type]['FP32']] for op_type in fp32_op_list]
+        
+        field_names = ["Op Type", "Total", "INT8", "BF16", "FP32"]
+        output_data = [[
+            op_type, sum(res[op_type].values()), 
+            res[op_type]['INT8'], res[op_type]['BF16'], res[op_type]['FP32']]
+        for op_type in fp32_op_list]
 
         Statistics(output_data,
                    header='Mixed Precision Statistics',
-                   field_names=["Op Type", "Total", "INT8", "BF16", "FP32"]).print_stat()
+                   field_names=field_names).print_stat()
+        self.optype_statistics = field_names, output_data
 
     def _query_bf16_ops(self, matched_nodes):
         self.bf16_op_details = OrderedDict()
@@ -809,7 +831,7 @@ class TensorFlowAdaptor(Adaptor):
         """
         from .tf_utils.graph_rewriter.generic.pre_optimize import PreOptimization
 
-        self.pre_optimizer_handle = PreOptimization(model, self.optimization, self.new_api)
+        self.pre_optimizer_handle = PreOptimization(model, self.optimization, self.new_api, self.device)
 
         self.pre_optimized_model = self.pre_optimizer_handle.get_optimized_model(self.itex_mode)
         model.graph_def = self.pre_optimized_model.graph_def
@@ -1405,7 +1427,7 @@ class TensorFlowAdaptor(Adaptor):
                 tf.compat.v1.GraphDef: the quantized model
         """
         from .tf_utils.graph_rewriter.generic.pre_optimize import PreOptimization
-        self.pre_optimizer_handle = PreOptimization(model, self.optimization, self.new_api)
+        self.pre_optimizer_handle = PreOptimization(model, self.optimization, self.new_api, self.device)
         self.pre_optimized_model = self.pre_optimizer_handle.get_optimized_model(self.itex_mode)
         model.graph_def = self.pre_optimized_model.graph_def
 
@@ -1426,9 +1448,6 @@ class TensorFlowAdaptor(Adaptor):
 class Tensorflow_ITEXAdaptor(TensorFlowAdaptor):
     def __init__(self, framework_specific_info):
         super().__init__(framework_specific_info)
-        from pkg_resources import parse_version
-        import tensorflow as tf
-        self.new_api = True if parse_version(tf.version.VERSION) >= parse_version('2.10.0') else False
 
     @dump_elapsed_time("Pass quantize model")
     def quantize(self, tune_cfg, model, data_loader, q_func=None):
@@ -1595,16 +1614,19 @@ class TensorflowQuery(QueryBackendCapability):
             try:
                 self.cur_config = self._get_specified_version_cfg(content)
                 if not self.performance_only:
-                    remove_int8_ops = ['FusedBatchNorm', 'FusedBatchNormV2', 'FusedBatchNormV3']
+                    remove_int8_ops = ['FusedBatchNorm', 'FusedBatchNormV2', 'FusedBatchNormV3',
+                                       '_MklFusedInstanceNorm']
                     for op in remove_int8_ops:
                         while op in self.cur_config['ops']['int8']:
                             self.cur_config['ops']['int8'].remove(op)
                         if self.cur_config.get('capabilities'):
                             self.cur_config['capabilities']['int8'].pop(op, None)
-                        pattern = f'Dequantize + {op} + Relu + QuantizeV2'
-                        if self.cur_config.get('patterns'):
-                            while pattern in self.cur_config['patterns']['int8']:
-                                self.cur_config['patterns']['int8'].remove(pattern)
+                        patterns = [f'Dequantize + {op} + Relu + QuantizeV2',
+                                    f'Dequantize + {op} + LeakyRelu + QuantizeV2']
+                        for pattern in patterns:
+                            if self.cur_config.get('patterns'):
+                                while pattern in self.cur_config['patterns']['int8']:
+                                    self.cur_config['patterns']['int8'].remove(pattern)
 
             except Exception as e:
                 logger.info("Fail to parse {} due to {}.".format(self.cfg, str(e)))
@@ -1774,16 +1796,3 @@ class TensorflowQuery(QueryBackendCapability):
                 final_out.append(_generate_pattern(similar_sequences))
 
         return final_out
-
-@adaptor_registry
-class IntelTensorFlowAdaptor(TensorFlowAdaptor):
-    def __init__(self, framework_specific_info):
-        super().__init__(framework_specific_info)
-        from pkg_resources import parse_version
-        import tensorflow as tf
-        self.new_api = True if parse_version(tf.version.VERSION) >= parse_version('2.10.0') else False
-        # not enable qdq mode for old api
-        if not self.new_api:
-            self.qdq_enabled = False
-            self.op_wise_sequences = self.query_handler.get_eightbit_patterns()
-
