@@ -336,7 +336,7 @@ class FuseMatMulRequantizeTransformer(GraphRewriterBase):
 
         return self.graph_analyzer.dump_graph()
 
-class FuseMatMulRequantizeDequantizeNewAPITransformer(GraphRewriterBase):
+class FuseMatMulRequantizeDequantizeNewAPITransformer(GraphRewriterBase): # pragma: no cover
     """Fuse _QuantizedMatMul + Requantize + Dequantize into _QuantizedMatMul.
     """
     def __init__(self, model, device='cpu'):
@@ -368,10 +368,10 @@ class FuseMatMulRequantizeDequantizeNewAPITransformer(GraphRewriterBase):
 
             quantized_node_op = i[-1][0]
             
-            if "BiasAdd" in quantized_node.attr["fused_ops"].SerializeToString().decode('UTF-8') \
-               and ("Relu" in quantized_node.attr["fused_ops"].SerializeToString().decode('UTF-8') and \
-                    "LeakyRelu" not in quantized_node.attr["fused_ops"].SerializeToString().decode('UTF-8') and \
-                    "Relu6" not in quantized_node.attr["fused_ops"].SerializeToString().decode('UTF-8')):
+            # "BiasAdd" + "Add" only supports "Dequantize"
+            attr_fused_ops = ''.join(x for x in quantized_node.attr["fused_ops"].SerializeToString()\
+                               .decode('UTF-8', 'ignore').strip() if x.isprintable())
+            if not "BiasAddAdd" in attr_fused_ops:
                 continue
 
             new_node = node_def_pb2.NodeDef()
@@ -399,25 +399,16 @@ class FuseMatMulRequantizeDequantizeNewAPITransformer(GraphRewriterBase):
                 new_node.attr["output_quant_mode"].CopyFrom(quantized_node.attr["output_quant_mode"])
 
             top_node_name = Helper.node_name_from_input(quantized_node.input[0])
-            attr_fused_ops = ''.join(x for x in quantized_node.attr["fused_ops"].SerializeToString()\
-                               .decode('UTF-8', 'ignore').strip() if x.isprintable())
             max_filter_node = None
             min_filter_node = None
 
             # MatMul + BiasAdd + Add
-            if "BiasAddAdd" in attr_fused_ops:
-                # The Min and Max of non-const weight node are from QuantizeV2's output, not valid nodes.
-                # Add check here for excluding this case.
-                if ":2" not in new_node.input[7]:
-                    max_filter_node = self.graph_info[new_node.input[7]].node
-                if ":1" not in new_node.input[6]:
-                    min_filter_node = self.graph_info[new_node.input[6]].node
-            # MatMul + BiasAdd
-            else:
-                if ":2" not in new_node.input[6]:
-                    max_filter_node = self.graph_info[new_node.input[6]].node
-                if ":1" not in new_node.input[5]:
-                    min_filter_node = self.graph_info[new_node.input[5]].node
+            # The Min and Max of non-const weight node are from QuantizeV2's output, not valid nodes.
+            # Add check here for excluding this case.
+            if ":2" not in new_node.input[7]:
+                max_filter_node = self.graph_info[new_node.input[7]].node
+            if ":1" not in new_node.input[6]:
+                min_filter_node = self.graph_info[new_node.input[6]].node
             last_node = self.graph_info[new_node.input[0]].node
             weight_node = self.graph_info[Helper.node_name_from_input(new_node.input[1])].node
             bias_node = self.graph_info[Helper.node_name_from_input(new_node.input[2])].node
@@ -501,34 +492,12 @@ class FuseMatMulRequantizeDequantizeNewAPITransformer(GraphRewriterBase):
 
             new_node.attr["Tbias"].CopyFrom(attr_value_pb2.AttrValue(type=type_bias))
 
-            if "BiasAddAdd" in attr_fused_ops:
-                Helper.set_attr_string_list(new_node, 'fused_ops', [b'BiasAdd', b'Add', b'Dequantize'])
-                Helper.set_attr_type_list(new_node, 'Thost_inputs', [
-                    uint8_type, int8_type, type_bias, float32_type, float32_type, float32_type, 
-                    float32_type, float32_type, float32_type, float32_type
-                    ])
-            else:
-                if "GeluApproximate" in  attr_fused_ops:
-                    Helper.set_attr_string_list(new_node, 'fused_ops', \
-                                [b'BiasAdd', b'GeluApproximate', b'Dequantize'])
-                elif "GeluExact" in attr_fused_ops:
-                    Helper.set_attr_string_list(new_node, 'fused_ops', [b'BiasAdd', b'GeluExact', b'Dequantize'])
-                elif "Elu" in attr_fused_ops:
-                    Helper.set_attr_string_list(new_node, 'fused_ops', [b'BiasAdd', b'Elu', b'Dequantize'])
-                elif "Tanh" in attr_fused_ops:
-                    Helper.set_attr_string_list(new_node, 'fused_ops', [b'BiasAdd', b'Tanh', b'Dequantize'])
-                elif "LeakyRelu" in attr_fused_ops:
-                    Helper.set_attr_string_list(new_node, 'fused_ops', [b'BiasAdd', b'LeakyRelu', b'Dequantize'])
-                elif "Relu6" in attr_fused_ops:
-                    Helper.set_attr_string_list(new_node, 'fused_ops', [b'BiasAdd', b'Relu6', b'Dequantize'])
-                elif "Sigmoid" in attr_fused_ops:
-                    Helper.set_attr_string_list(new_node, 'fused_ops', [b'BiasAdd', b'Sigmoid', b'Dequantize'])
-                else:
-                    Helper.set_attr_string_list(new_node, 'fused_ops', [b'BiasAdd', b'Dequantize'])
-                Helper.set_attr_type_list(new_node, 'Thost_inputs', [
-                    uint8_type, int8_type, type_bias, float32_type, float32_type,
-                    float32_type, float32_type, float32_type, float32_type
-                    ])
+            Helper.set_attr_string_list(new_node, 'fused_ops', [b'BiasAdd', b'Add', b'Dequantize'])
+            Helper.set_attr_type_list(new_node, 'Thost_inputs', [
+                uint8_type, int8_type, type_bias, float32_type, float32_type, float32_type, 
+                float32_type, float32_type, float32_type, float32_type
+                ])
+
             Helper.set_attr_type_list(new_node, 'Thost_outputs', [float32_type])
             new_node.attr["Tout"].CopyFrom(attr_value_pb2.AttrValue(type=float32_type))
 
@@ -582,10 +551,12 @@ class FuseMatMulRequantizeNewAPITransformer(GraphRewriterBase):
             requested_output_max_name = requantize_node.input[4]
 
             quantized_node_op = i[-1][0]
-            if ("BiasAdd" in quantized_node.attr["fused_ops"].SerializeToString().decode('UTF-8') \
-               and "Relu" not in quantized_node.attr["fused_ops"].SerializeToString().decode('UTF-8')) or \
-               ("Relu6" in quantized_node.attr["fused_ops"].SerializeToString().decode('UTF-8')) or \
-               ("LeakyRelu" in quantized_node.attr["fused_ops"].SerializeToString().decode('UTF-8')):
+            attr_fused_ops = ''.join(x for x in quantized_node.attr["fused_ops"].SerializeToString()\
+                               .decode('UTF-8', 'ignore').strip() if x.isprintable())
+            # "Requantize"
+            # "BiasAdd", "Requantize"
+            # "BiasAdd", "Activation", "Requantize"
+            if "BiasAddAdd" in attr_fused_ops:
                 continue
 
             new_node = node_def_pb2.NodeDef()
@@ -600,7 +571,7 @@ class FuseMatMulRequantizeNewAPITransformer(GraphRewriterBase):
             if 'transpose_b' in quantized_node.attr:
                 new_node.attr["transpose_b"].CopyFrom(quantized_node.attr['transpose_b'])
             if 'transpose_a' in quantized_node.attr:
-                new_node.attr["transpose_a"].CopyFrom(quantized_node.attr['transpose_a'])  
+                new_node.attr["transpose_a"].CopyFrom(quantized_node.attr['transpose_a'])
             if 'T1' in quantized_node.attr:
                 new_node.attr["T1"].CopyFrom(quantized_node.attr['T1'])
             if 'T2' in quantized_node.attr:
@@ -624,11 +595,14 @@ class FuseMatMulRequantizeNewAPITransformer(GraphRewriterBase):
             last_node = self.graph_info[new_node.input[0]].node
             is_min_first = bool(quantized_node.attr['input_quant_mode'].s == b'MIN_FIRST')
             weight_node = self.graph_info[new_node.input[1]].node
-            bias_node = self.graph_info[new_node.input[2]].node
-            max_input_node = self.graph_info[last_node.input[-1]].node
-            min_input_node = self.graph_info[last_node.input[-2]].node
+            bias_node = None
+            if "BiasAdd" in attr_fused_ops:
+                bias_node = self.graph_info[new_node.input[2]].node
+            if not last_node.op == 'QuantizedConcatV2':
+                max_input_node = self.graph_info[last_node.input[-1]].node
+                min_input_node = self.graph_info[last_node.input[-2]].node
 
-            if max_input_node.op == 'Enter': # pragma: no cover
+            if not last_node.op == 'QuantizedConcatV2' and max_input_node.op == 'Enter': # pragma: no cover
                 min_input_parent_name = Helper.node_name_from_input(min_input_node.input[0])
                 max_input_parent_name = Helper.node_name_from_input(max_input_node.input[0])
                 min_input_parent_node = self.graph_info[min_input_parent_name].node
@@ -653,7 +627,7 @@ class FuseMatMulRequantizeNewAPITransformer(GraphRewriterBase):
                     continue
                 weight_node = weight_parent_node
             bias_enter_node = None
-            if bias_node.op == 'Enter': # pragma: no cover
+            if bias_node and bias_node.op == 'Enter': # pragma: no cover
                 bias_enter_node = bias_node
                 bias_parent_name = Helper.node_name_from_input(bias_node.input[0])
                 bias_parent_node = self.graph_info[bias_parent_name].node
@@ -661,8 +635,8 @@ class FuseMatMulRequantizeNewAPITransformer(GraphRewriterBase):
                     continue
                 bias_node = bias_parent_node
 
-            if last_node.op.find('_QuantizedMatMul') != -1 or last_node.op.find('QuantizeV2') != -1 \
-               and max_filter_node and min_filter_node:
+            if bias_node and (last_node.op.find('_QuantizedMatMul') != -1 or last_node.op.find('QuantizeV2') != -1 \
+               and max_filter_node and min_filter_node):
                 min_input_value = (min_input_node.attr['value'].tensor.float_val)[0]
                 max_input_value = (max_input_node.attr['value'].tensor.float_val)[0]
                 max_filter_value = (max_filter_node.attr['value'].tensor.float_val)[0]
@@ -700,11 +674,9 @@ class FuseMatMulRequantizeNewAPITransformer(GraphRewriterBase):
                 new_node.attr["Tbias"].CopyFrom(attr_value_pb2.AttrValue(type=float32_type \
                                                 if self.device == 'gpu' else qint32_type))
 
-                #TODO enabled below commit once the graph refactor pre_optimize commmitted.
-                if "Relu" in quantized_node.attr["fused_ops"].SerializeToString().decode('UTF-8'):
-                    deq_node_name = self.graph_info[requantize_node_name].outputs[0]
-                    deq_node = self.graph_info[deq_node_name].node
-                    deq_node.attr['T'].CopyFrom(attr_value_pb2.AttrValue(type=uint8_type))
+                deq_node_name = self.graph_info[requantize_node_name].outputs[0]
+                deq_node = self.graph_info[deq_node_name].node
+                deq_node.attr['T'].CopyFrom(attr_value_pb2.AttrValue(type=uint8_type))
 
                 Helper.set_attr_type_list(new_node, "Thost_inputs", [
                                         uint8_type, int8_type,
@@ -713,15 +685,44 @@ class FuseMatMulRequantizeNewAPITransformer(GraphRewriterBase):
                                         float32_type, float32_type, float32_type])
             else:
                 new_node.attr["Tbias"].CopyFrom(attr_value_pb2.AttrValue(type=float32_type))
-                Helper.set_attr_type_list(new_node, "Thost_inputs", [
-                                        uint8_type, int8_type, float32_type,
-                                        float32_type, float32_type, float32_type,
-                                        float32_type, float32_type, float32_type])
+                deq_node_name = self.graph_info[requantize_node_name].outputs[0]
+                deq_node = self.graph_info[deq_node_name].node
+                deq_node.attr['T'].CopyFrom(attr_value_pb2.AttrValue(type=uint8_type))
+                if bias_node:
+                    Helper.set_attr_type_list(new_node, "Thost_inputs", [
+                                            uint8_type, int8_type, float32_type,
+                                            float32_type, float32_type, float32_type,
+                                            float32_type, float32_type, float32_type])
+                else:
+                    Helper.set_attr_type_list(new_node, "Thost_inputs", [
+                                            uint8_type, int8_type,
+                                            float32_type, float32_type, float32_type,
+                                            float32_type, float32_type, float32_type])
 
             Helper.set_attr_type_list(new_node, 'Thost_outputs', [
                                       uint8_type, float32_type, float32_type])
 
-            Helper.set_attr_string_list(new_node, 'fused_ops', [b'BiasAdd', b'Relu', b'Requantize'])
+            if "GeluApproximate" in  attr_fused_ops:
+                Helper.set_attr_string_list(new_node, 'fused_ops', \
+                            [b'BiasAdd', b'GeluApproximate', b'Requantize'])
+            elif "GeluExact" in attr_fused_ops:
+                Helper.set_attr_string_list(new_node, 'fused_ops', [b'BiasAdd', b'GeluExact', b'Requantize'])
+            elif "Elu" in attr_fused_ops:
+                Helper.set_attr_string_list(new_node, 'fused_ops', [b'BiasAdd', b'Elu', b'Requantize'])
+            elif "LeakyRelu" in attr_fused_ops:
+                Helper.set_attr_string_list(new_node, 'fused_ops', [b'BiasAdd', b'LeakyRelu', b'Requantize'])
+            elif "Relu6" in attr_fused_ops:
+                Helper.set_attr_string_list(new_node, 'fused_ops', [b'BiasAdd', b'Relu6', b'Requantize'])
+            elif "Tanh" in attr_fused_ops:
+                Helper.set_attr_string_list(new_node, 'fused_ops', [b'BiasAdd', b'Tanh', b'Requantize'])
+            elif "Sigmoid" in attr_fused_ops:
+                Helper.set_attr_string_list(new_node, 'fused_ops', [b'BiasAdd', b'Sigmoid', b'Requantize'])
+            elif "Relu" in attr_fused_ops:
+                Helper.set_attr_string_list(new_node, 'fused_ops', [b'BiasAdd', b'Relu', b'Requantize'])
+            elif "BiasAdd" in attr_fused_ops:
+                Helper.set_attr_string_list(new_node, 'fused_ops', [b'BiasAdd', b'Requantize'])
+            else:
+                Helper.set_attr_string_list(new_node, 'fused_ops', [b'Requantize'])
             new_node.attr["Tout"].CopyFrom(attr_value_pb2.AttrValue(type=uint8_type))
 
             self.graph_analyzer.replace_single_node(
