@@ -17,6 +17,7 @@
 
 import copy
 import numpy as np
+from collections import namedtuple
 from tensorflow.python.framework import dtypes
 from tensorflow.python.framework import tensor_util
 from neural_compressor.utils.utility import dump_elapsed_time
@@ -47,13 +48,17 @@ class GenerateGraphWithQDQPattern(GraphRewriterBase):
         self.device = device
         self.performance_only = performance_only
         self.itex_mode = itex_mode
-
+        self.node_details = namedtuple('node_details', ['node', 'output'])
         self.node_name_mapping = {}
         for node in self.model.node:
-            if node.name not in self.node_name_mapping:
-                self.node_name_mapping[node.name] = node
-            else:
-                raise ValueError("Duplicate node names detected for ", node.name)
+            if node.name in self.node_name_mapping:
+                raise ValueError("Duplicate Node Found when _parse_graph, the node name is {}" \
+                    .format(node.name))
+            self.node_name_mapping[node.name] = self.node_details(node=node, output=[])
+        for node_name in self.node_name_mapping:
+            for each_input in self.node_name_mapping[node_name].node.input:
+                self.node_name_mapping \
+                    [Helper.node_name_from_input(each_input)].output.append(node_name)
 
     @dump_elapsed_time("Pass GenerateGraphWithQDQPattern")
     def do_transformation(self):
@@ -97,7 +102,8 @@ class GenerateGraphWithQDQPattern(GraphRewriterBase):
         self.g_weight.graph = self.g.dump_graph()
         self.graph_info = self.g_weight.parse_graph()
         target_nodes = self.g_weight.query_fusion_pattern_nodes(
-               [["Conv2D", "Conv3D", "DepthwiseConv2dNative", "MatMul", "BatchMatMul", "BatchMatMulV2"]])
+               [["Conv2D", "Conv3D", "DepthwiseConv2dNative", "MatMul", \
+                 "BatchMatMul", "BatchMatMulV2", "Conv2DBackpropInput", "Conv3DBackpropInputV2"]])
         for i in target_nodes:
             if i[0] not in quantizable_op_names:
                 continue
@@ -174,8 +180,9 @@ class GenerateGraphWithQDQPattern(GraphRewriterBase):
     def _check_op_list(self, node_type):
         op_list = ("ConcatV2", "Conv2D", "Conv3D", "DepthwiseConv2D", "QuantizeV2", "DepthwiseConv2dNative",
                    "MaxPool", "MaxPool3D", "FusedBatchNormV3", "Requantize", "RequantizePerChannel", "AvgPool", "Pad",
-                   "CropAndResize", "Dequantize", "Mean", "MatMul", "BatchMatMul",
-                   "BatchMatMulV2", "FakeQuantWithMinMaxVars")
+                   "CropAndResize", "Dequantize", "Mean", "MatMul", "BatchMatMul", "BatchMatMulV2",
+                   "FakeQuantWithMinMaxVars", "_MklFusedInstanceNorm",
+                   "Conv2DBackpropInput", "Conv3DBackpropInputV2")
         return any([node_type.find(i) != -1 for i in op_list])
 
     def _find_relu_node(self, node):
@@ -185,10 +192,12 @@ class GenerateGraphWithQDQPattern(GraphRewriterBase):
                 and (node.op != "Relu"
                      or not self.performance_only
                      or self.node_name_mapping \
-                        [Helper.node_name_from_input(node.input[0])].op.find("FusedBatchNorm") == -1
+                        [Helper.node_name_from_input(node.input[0])].node.op.find("FusedBatchNorm") == -1
                      or self.node_name_mapping \
-                        [Helper.node_name_from_input(node.input[0])].attr['is_training'].b):
-            return True
+                        [Helper.node_name_from_input(node.input[0])].node.attr['is_training'].b
+                     or len(self.node_name_mapping \
+                        [Helper.node_name_from_input(node.input[0])].output) > 1):
+                        return True
         elif 'T' in node.attr and node.attr['T'].type in (dtypes.quint8, dtypes.uint8):
             return True
         elif (node.op.find("QuantizedConv") != -1
@@ -202,30 +211,34 @@ class GenerateGraphWithQDQPattern(GraphRewriterBase):
                 find_relu = False
                 for i in range(0,node.attr['N'].i):
                     if re.search(r"\w+:\d+", node.input[i]):
-                        input_node = self.node_name_mapping[node.input[i].rsplit(':', 1)[0]]
+                        input_node = self.node_name_mapping[node.input[i].rsplit(':', 1)[0]].node
                     else:
-                        input_node = self.node_name_mapping[node.input[i]]
+                        input_node = self.node_name_mapping[node.input[i]].node
                     find_relu |= self._find_relu_node(input_node)
                 return find_relu
             else:
                 if re.search(r"\w+:\d+", node.input[0]):
-                    input_node = self.node_name_mapping[node.input[0].rsplit(':', 1)[0]]
+                    input_node = self.node_name_mapping[node.input[0].rsplit(':', 1)[0]].node
                 else:
-                    input_node = self.node_name_mapping[node.input[0]]
+                    input_node = self.node_name_mapping[node.input[0]].node
                 return self._find_relu_node(input_node)
         else:
             return False
 
     def _insert_qdq_pattern_for_common_ops(self, original_node, is_asymmetric):
         namespace_prefix = original_node.name + "_eightbit"
-        for each_input_name in self.node_name_mapping[original_node.name].input[:1]:
+        if original_node.op in ("Conv2DBackpropInput", "Conv3DBackpropInputV2"):
+            all_inputs = self.node_name_mapping[original_node.name].node.input[-1:]
+        else:
+            all_inputs = self.node_name_mapping[original_node.name].node.input[:1]
+        for each_input_name in all_inputs:
             if each_input_name[0] == '^':
                 continue
 
-            if self.node_name_mapping[original_node.name].op == "MatMul":
+            if self.node_name_mapping[original_node.name].node.op == "MatMul":
                 dtype = dtypes.quint8
-            elif self.node_name_mapping[original_node.name].op == "BatchMatMulV2" \
-                 or self.node_name_mapping[original_node.name].op == "BatchMatMul":
+            elif self.node_name_mapping[original_node.name].node.op == "BatchMatMulV2" \
+                or self.node_name_mapping[original_node.name].node.op == "BatchMatMul":
                 dtype = dtypes.qint8
             else:
                 input_node_name = Helper.node_name_from_input(each_input_name)
@@ -233,13 +246,13 @@ class GenerateGraphWithQDQPattern(GraphRewriterBase):
                     if self.graph_info[input_node_name].node.op == "Dequantize":
                         dtype = dtypes.DType(
                             self.graph_info[input_node_name].node.attr["T"].type)
-                    elif self._find_relu_node(self.node_name_mapping[original_node.name]):
+                    elif self._find_relu_node(self.node_name_mapping[original_node.name].node):
                         dtype = dtypes.quint8
                     else:
                         dtype = dtypes.qint8
                 else:
                     dtype = dtypes.quint8 if self._find_relu_node(
-                        self.node_name_mapping[original_node.name]
+                        self.node_name_mapping[original_node.name].node
                     ) else dtypes.qint8
             self._insert_qdq_pattern_for_each_input(original_node.name,
                                                     namespace_prefix,
@@ -360,7 +373,7 @@ class GenerateGraphWithQDQPattern(GraphRewriterBase):
             if not is_asymmetric:
                 Helper.set_attr_string(quant_v2_node, "round_mode", b"HALF_TO_EVEN")
             #Helper.set_attr_bool(quant_v2_node, "narrow_range", False if is_asymmetric else True)
-            if "BatchMatMul" in self.graph_info[op_name].node.op:
+            if self.performance_only or "BatchMatMul" in self.graph_info[op_name].node.op:
                 Helper.set_attr_string(
                     quant_v2_node, "mode", b"SCALED")
             else:
@@ -376,15 +389,17 @@ class GenerateGraphWithQDQPattern(GraphRewriterBase):
                     "Dequantize", op_name + '_dequantize',
                     [quant_v2_node.name, quant_v2_node.name + ':1', quant_v2_node.name + ':2'])
             Helper.set_attr_dtype(dequantize_node, "T", dtype)
-            if "BatchMatMul" in self.graph_info[op_name].node.op:
+            if self.performance_only or "BatchMatMul" in self.graph_info[op_name].node.op:
                 Helper.set_attr_string(
                     dequantize_node, "mode", b"SCALED")
             else:
                 Helper.set_attr_string(
                     dequantize_node, "mode", b"MIN_FIRST" if is_asymmetric else b"SCALED")
+            if self.graph_info[op_name].node.op in ("Conv2DBackpropInput", "Conv3DBackpropInputV2"):
+                input_index = 2
 
             self.g.add_node(quant_v2_node,
-                            self.graph_info[op_name].node.input[0],
+                            self.graph_info[op_name].node.input[input_index],
                             [dequantize_node.name])
             self.g.add_node(dequantize_node, quant_v2_node.name, [op_name])
             self.g.add_node(reshape_dims_node, None, [reshape_input_name])
@@ -414,12 +429,13 @@ class GenerateGraphWithQDQPattern(GraphRewriterBase):
        
         # The weight node of BatchMatMul may have no value
         if 'value' in weight_node.attr and \
-           host_op_type in ("Conv2D", "MatMul", "BatchMatMul", "BatchMatMulV2", "Conv3D"):
+           host_op_type in ("Conv2D", "MatMul", "BatchMatMul", "BatchMatMulV2", "Conv3D", \
+                            "Conv2DBackpropInput", "Conv3DBackpropInputV2"):
             float_tensor = tensor_util.MakeNdarray(weight_node.attr["value"].tensor)
             if per_channel:
-                if host_op_type == 'Conv3D':
+                if host_op_type in ('Conv3D', 'Conv3DBackpropInputV2'):
                     ranges = np.abs(float_tensor).max(axis=(0, 1, 2, 3))
-                elif host_op_type == 'Conv2D':
+                elif host_op_type in ('Conv2D', 'Conv2DBackpropInput'):
                     ranges = np.abs(float_tensor).max(axis=(0, 1, 2))
                 else:
                     ranges = np.abs(float_tensor).max(axis=(0, 1))
@@ -510,10 +526,10 @@ class GenerateGraphWithQDQPattern(GraphRewriterBase):
         Helper.set_attr_dtype(dequant_node, "T", dtypes.qint8)
         Helper.set_attr_string(dequant_node, "mode", b"SCALED")
         if per_channel:
-            if host_op_type == 'Conv2D':
+            if host_op_type == 'Conv2D' or host_op_type == 'Conv2DBackpropInput':
                 Helper.set_attr_int(quant_node, 'axis', 3)
                 Helper.set_attr_int(dequant_node, 'axis', 3)
-            elif host_op_type == 'Conv3D':
+            elif host_op_type == 'Conv3D' or host_op_type == 'Conv3DBackpropInputV2':
                 Helper.set_attr_int(quant_node, 'axis', 4)
                 Helper.set_attr_int(dequant_node, 'axis', 4)
             elif host_op_type == 'MatMul':
@@ -573,6 +589,8 @@ class GenerateGraphWithQDQPattern(GraphRewriterBase):
                 return True
         if "FusedBatchNorm" in self.graph_info[matched_node_name].node.op:
             return True
+        if "_MklFusedInstanceNorm" == self.graph_info[matched_node_name].node.op:
+            return True
         return False
 
 
