@@ -265,7 +265,8 @@ class QuantizeNodeBase():
     def _need_to_check(self, node_type):
         op_list = ("ConcatV2", "Conv2D", "Conv3D", "DepthwiseConv2D", "QuantizeV2", "DepthwiseConv2dNative",
                    "MaxPool", "MaxPool3D", "FusedBatchNormV3", "Requantize", "RequantizePerChannel", "AvgPool", "Pad",
-                   "CropAndResize", "Dequantize", "Mean", "MatMul", "BatchMatMulV2", "FakeQuantWithMinMaxVars")
+                   "CropAndResize", "Dequantize", "Mean", "MatMul", "BatchMatMulV2", "FakeQuantWithMinMaxVars",
+                   "_MklFusedInstanceNorm")
         return any([node_type.find(i) != -1 for i in op_list])
 
     def _find_relu_node(self, node):
@@ -280,8 +281,10 @@ class QuantizeNodeBase():
                      or self.node_name_mapping \
                         [helper.node_name_from_input(node.input[0])].node.op.find("FusedBatchNorm") == -1
                      or self.node_name_mapping \
-                        [helper.node_name_from_input(node.input[0])].node.attr['is_training'].b):
-            return True
+                        [helper.node_name_from_input(node.input[0])].node.attr['is_training'].b
+                     or len(self.node_name_mapping \
+                        [helper.node_name_from_input(node.input[0])].output) > 1):
+                        return True
         elif 'T' in node.attr and node.attr['T'].type in (dtypes.quint8, dtypes.uint8):
             return True
         elif (node.op.find("QuantizedConv") != -1
@@ -322,7 +325,8 @@ class QuantizeNodeBase():
                                               quantized_output_name,
                                               original_node_name,
                                               dtype=dtypes.quint8,
-                                              min_tensor_index=1):
+                                              min_tensor_index=1,
+                                              performance_only=False):
         min_max_inputs = [
             "%s:%s" % (quantized_output_name, min_tensor_index),
             "%s:%s" % (quantized_output_name, min_tensor_index + 1)
@@ -333,8 +337,11 @@ class QuantizeNodeBase():
             "Dequantize", dequantize_name,
             [quantized_output_name, min_max_inputs[0], min_max_inputs[1]])
         helper.set_attr_dtype(dequantize_node, "T", dtype)
-        helper.set_attr_string(dequantize_node, "mode",
-                               b"MIN_FIRST" if self.is_asymmetric else b"SCALED")
+        if performance_only:
+            helper.set_attr_string(dequantize_node, "mode", b"SCALED")
+        else:
+            helper.set_attr_string(dequantize_node, "mode",
+                                b"MIN_FIRST" if self.is_asymmetric else b"SCALED")
         self.add_output_graph_node(dequantize_node)
 
     def eightbitize_single_input_tensor_node(self, original_node,
