@@ -93,7 +93,7 @@ class RerangeQuantizedConcat(GraphTransformBase):
                 concat_input_node_op_type = concat_input_node.op
                 if concat_input_node_op_type in self.offset_map:
                     quantized_conv_nodes.append(concat_input_node)
-                elif concat_input_node.op == "_QuantizedConv2D" and \
+                elif concat_input_node.op == "_FusedQuantizedConv2D" and \
                       'fused_ops' in concat_input_node.attr and \
                       str(concat_input_node.attr['fused_ops'].list.s) in self.offset_map_new_api:
                     quantized_conv_nodes.append(concat_input_node) 
@@ -103,7 +103,7 @@ class RerangeQuantizedConcat(GraphTransformBase):
                         self.get_node_name_from_input(
                             concat_input_node.input[0])]
                     if self.performance_only:
-                        if another_concat_node.op == "_QuantizedConv2D" and \
+                        if another_concat_node.op == "_FusedQuantizedConv2D" and \
                         'fused_ops' in another_concat_node.attr and \
                         str(another_concat_node.attr['fused_ops'].list.s) in self.offset_map_new_api:
                             quantized_conv_nodes.append(another_concat_node)
@@ -125,7 +125,7 @@ class RerangeQuantizedConcat(GraphTransformBase):
 
             return can_rerange
         elif op_type == "QuantizedConv2DWithBiasAndReluAndRequantize" or \
-              (input_node.op == "_QuantizedConv2D" and \
+              (input_node.op == "_FusedQuantizedConv2D" and \
               'fused_ops' in input_node.attr and \
               input_node.attr['fused_ops'].list.s in self.fuse_requantized_relu_op_new_api):
             can_rerange = True
@@ -151,7 +151,7 @@ class RerangeQuantizedConcat(GraphTransformBase):
             for node in quantized_conv_nodes:
 
                 offset_value = 6 
-                if node.op == "_QuantizedConv2D" and \
+                if node.op == "_FusedQuantizedConv2D" and \
                       'fused_ops' in node.attr and \
                       str(node.attr['fused_ops'].list.s) in self.offset_map_new_api:
                     offset_value = self.offset_map_new_api[str(node.attr['fused_ops'].list.s)]
@@ -176,7 +176,7 @@ class RerangeQuantizedConcat(GraphTransformBase):
 
             for node in quantized_conv_nodes:
                 offset_value = 6
-                if node.op == "_QuantizedConv2D" and \
+                if node.op == "_FusedQuantizedConv2D" and \
                    'fused_ops' in node.attr and \
                    str(node.attr['fused_ops'].list.s) in self.offset_map_new_api:
                     offset_value = self.offset_map_new_api[str(node.attr['fused_ops'].list.s)]
@@ -209,7 +209,7 @@ class RerangeQuantizedConcat(GraphTransformBase):
             current_node = self.node_mapping[node_name]
             current_node_op = current_node.op
             if (current_node_op in self.fused_requantized_bias_op) or \
-              (current_node_op == "_QuantizedConv2D" and \
+              (current_node_op == "_FusedQuantizedConv2D" and \
               'fused_ops' in current_node.attr and \
               current_node.attr['fused_ops'].list.s in self.fuse_requantized_bias_op_new_api):
                 done = False
@@ -221,7 +221,7 @@ class RerangeQuantizedConcat(GraphTransformBase):
                     if current_node.op in self.offset_map:
                         another_conv_node = current_node
                         done = True
-                    elif current_node.op == "_QuantizedConv2D" and \
+                    elif current_node.op == "_FusedQuantizedConv2D" and \
                           'fused_ops' in current_node.attr and \
                           str(current_node.attr['fused_ops'].list.s) in self.offset_map_new_api:
                         another_conv_node = current_node
@@ -243,7 +243,7 @@ class RerangeQuantizedConcat(GraphTransformBase):
                 if bias_node_type.type != dtypes.float32 or bias_node_type.type == dtypes.qint32:
                     continue
                 sum_off_set = 0 
-                if original_conv_node.op == "_QuantizedConv2D":
+                if original_conv_node.op == "_FusedQuantizedConv2D":
                     if str(original_conv_node.attr['fused_ops'].list.s) == \
                        str([b'BiasAdd', b'Sum', b'Relu', b'Requantize']) \
                        or str(original_conv_node.attr['fused_ops'].list.s) == \
@@ -272,7 +272,7 @@ class RerangeQuantizedConcat(GraphTransformBase):
                         min_filter_node.attr['value'].tensor)
                
                 offset_value = 6
-                if another_conv_node.op == "_QuantizedConv2D" and \
+                if another_conv_node.op == "_FusedQuantizedConv2D" and \
                       'fused_ops' in another_conv_node.attr and \
                       str(another_conv_node.attr['fused_ops'].list.s) in self.offset_map_new_api:
                     offset_value = self.offset_map_new_api[str(another_conv_node.attr['fused_ops'].list.s)]
