@@ -173,17 +173,27 @@ def load(checkpoint_dir=None, model=None, history_cfg=None, **kwargs):
     Returns:
         (object): quantized model
     """
+
+
     if checkpoint_dir is not None:
         if isinstance(checkpoint_dir, dict):
             stat_dict = checkpoint_dir
         elif os.path.isfile(checkpoint_dir):
             weights_file = checkpoint_dir
-            stat_dict = torch.load(weights_file)
+            try:
+                stat_dict = torch.jit.load(weights_file)
+                logger.info("torch.jit.load is used to recovery the int8 model quantized by INC IPEX backend")
+            except:
+                stat_dict = torch.load(weights_file)
         elif os.path.isdir(checkpoint_dir):
             try:
                 weights_file = os.path.join(os.path.abspath(os.path.expanduser(checkpoint_dir)),
-                                            'best_model.pt')
-                stat_dict = torch.load(weights_file)
+                                           'best_model.pt')
+                try:
+                    stat_dict = torch.jit.load(weights_file)
+                    logger.info("torch.jit.load is used to recovery the int8 model quantized by INC IPEX backend")
+                except:
+                    stat_dict = torch.load(weights_file)
             except:
                 tune_cfg_file = os.path.join(os.path.abspath(os.path.expanduser(checkpoint_dir)),
                                             'best_configure.yaml')
@@ -196,10 +206,16 @@ def load(checkpoint_dir=None, model=None, history_cfg=None, **kwargs):
         else:
             logger.error("Unexpected checkpoint type:{}. \
               Only file dir/path or state_dict is acceptable")
-        assert 'best_configure' in stat_dict, \
-          "No best_configure found in the model file, " \
-          "please use the int8 model file generated by INC"
-        tune_cfg = stat_dict.pop('best_configure')
+
+        if isinstance(stat_dict, torch.jit._script.RecursiveScriptModule):
+            q_model = torch.jit.freeze(stat_dict.eval())
+            logger.info("finish load INC int8 IPEX model.")
+            return q_model
+        else:
+            assert 'best_configure' in stat_dict, \
+            "No best_configure found in the model file, " \
+            "please use the int8 model file generated by INC"
+            tune_cfg = stat_dict.pop('best_configure')
     else:
         assert history_cfg is not None, \
           "Need chieckpoint_dir or history_cfg to rebuild int8 model"
