@@ -19,6 +19,10 @@ log = logging.getLogger()
 log.name = "INC Bench"
 log.setLevel(level=logging.CRITICAL)
 
+fh = logging.FileHandler("bench.log")
+fh.setLevel(logging.DEBUG)
+log.addHandler(fh)
+
 
 def change_log_level(log_level: int) -> None:
     """Change log level."""
